pub enum SoundError {
UnsupportedChannelCount,
UnsupportedFeature,
InvalidFormat,
}Expand description
An error that prevents successful decoding of an audio stream.
Variants
UnsupportedChannelCount
The channel count is unsupported. Only mono and stero sounds are supported.
UnsupportedFeature
A feature in the audio file isn’t supported by the parser.
InvalidFormat
The audio file not formatted correctly for the encoding.