Storm application identifier.
Range up to 0..0x8000 is reserved for applications registered as
LNPBP standards. Range 0x8000-0xFFFF (custom user range) can be used
by any application without registration.
It is strongly advised to use random numbers from custom user range;
for instance by taking first two bytes of the SHA256 hash of the
application name or developer domain name and do a binary OR operation
with 0x8000.
Variants
Rgb
RGB smart contracts.
Future(u16)
Future applications. Numbers are reserved for LNPBP standardized apps.
Vendor(u16)
Vendor-specific applications which does not standardized by LNP/BP Standards Association.
Implementations