Struct storm::p2p::DeclineResp
source · [−]Fields
app: StormAppmesg_id: MesgIdTrait Implementations
sourceimpl Clone for DeclineResp
impl Clone for DeclineResp
sourcefn clone(&self) -> DeclineResp
fn clone(&self) -> DeclineResp
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for DeclineResp
impl Debug for DeclineResp
sourceimpl Display for DeclineResp
impl Display for DeclineResp
sourceimpl PartialEq<DeclineResp> for DeclineResp
impl PartialEq<DeclineResp> for DeclineResp
sourcefn eq(&self, other: &DeclineResp) -> bool
fn eq(&self, other: &DeclineResp) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &DeclineResp) -> bool
fn ne(&self, other: &DeclineResp) -> bool
This method tests for !=.
sourceimpl StrictDecode for DeclineResp
impl StrictDecode for DeclineResp
sourcefn strict_decode<D: Read>(d: D) -> Result<Self, Error>
fn strict_decode<D: Read>(d: D) -> Result<Self, Error>
Decode with the given std::io::Read instance; must either
construct an instance or return implementation-specific error type. Read more
sourcefn strict_deserialize(data: impl AsRef<[u8]>) -> Result<Self, Error>
fn strict_deserialize(data: impl AsRef<[u8]>) -> Result<Self, Error>
Tries to deserialize byte array into the current type using
StrictDecode::strict_decode Read more
sourceimpl StrictEncode for DeclineResp
impl StrictEncode for DeclineResp
sourcefn strict_encode<E: Write>(&self, e: E) -> Result<usize, Error>
fn strict_encode<E: Write>(&self, e: E) -> Result<usize, Error>
Encode with the given std::io::Write instance; must return result
with either amount of bytes encoded – or implementation-specific
error type. Read more
sourcefn strict_serialize(&self) -> Result<Vec<u8, Global>, Error>
fn strict_serialize(&self) -> Result<Vec<u8, Global>, Error>
Serializes data as a byte array using StrictEncode::strict_encode
function Read more
impl Eq for DeclineResp
impl StructuralEq for DeclineResp
impl StructuralPartialEq for DeclineResp